@@ -56,5 +56,11 @@ private:
 
     friend class ::RichTextComposerNgTest; // for fixHtmlFontSize
     void fixHtmlFontSize(QString &cleanHtml) const;
+    MESSAGECOMPOSER_NO_EXPORT void applyUnderlineFormat();
+    MESSAGECOMPOSER_NO_EXPORT void applyBoldFormat();
+    MESSAGECOMPOSER_NO_EXPORT void applyItalicFormat();
+    MESSAGECOMPOSER_NO_EXPORT void applyStrikeOutFormat();
+    MESSAGECOMPOSER_NO_EXPORT void insertFormat(QChar formatChar);
+    MESSAGECOMPOSER_NO_EXPORT void applyInsertLink();
 };
 }
