@@ -11,7 +11,7 @@
 #include "attachmentloadjob.h"
 
 #include <QUrl>
-
+#include <memory>
 namespace MessageCore
 {
 /**
@@ -28,12 +28,12 @@ public:
     /**
      * Returns the url that will be loaded as attachment.
      */
-    Q_REQUIRED_RESULT QUrl url() const;
+    [[nodiscard]] QUrl url() const;
 
     /**
      * Returns the maximum size the attachment is allowed to have.
      */
-    Q_REQUIRED_RESULT qint64 maximumAllowedSize() const;
+    [[nodiscard]] qint64 maximumAllowedSize() const;
 
     /**
      * Sets the @p url of the folder that will be loaded as attachment.
@@ -46,11 +46,11 @@ public:
     void setMaximumAllowedSize(qint64 size);
 
 protected Q_SLOTS:
-    virtual void doStart() override = 0;
+    void doStart() override = 0;
 
 private:
     //@cond PRIVATE
-    class Private;
-    Private *const d;
+    class AttachmentFromUrlBaseJobPrivate;
+    std::unique_ptr<AttachmentFromUrlBaseJobPrivate> const d;
 };
 }
