@@ -18,6 +18,8 @@
 #include <KLocalizedString>
 #include <QIcon>
 #include <QPointer>
+using namespace Qt::Literals::StringLiterals;
+
 using namespace MessageList::Core;
 
 Q_GLOBAL_STATIC(TagCache, s_tagCache)
@@ -26,7 +28,7 @@ class MessageItem::Tag::TagPrivate
 {
 public:
     TagPrivate()
-        : mPriority(0) // Initialize it
+
     {
     }
 
@@ -36,7 +38,7 @@ public:
     QColor mTextColor;
     QColor mBackgroundColor;
     QFont mFont;
-    int mPriority;
+    int mPriority{0};
 };
 
 MessageItem::Tag::Tag(const QPixmap &pix, const QString &tagName, const QString &tagId)
@@ -172,7 +174,7 @@ void MessageItemPrivate::fillTagList(const Akonadi::Tag::List &taglist)
     // Priority sort this and make bestTag more efficient
 
     for (const Akonadi::Tag &tag : taglist) {
-        QString symbol = QStringLiteral("mail-tagged");
+        QString symbol = u"mail-tagged"_s;
         const auto attr = tag.attribute<Akonadi::TagAttribute>();
         if (attr) {
             if (!attr->iconName().isEmpty()) {
@@ -218,13 +220,13 @@ bool MessageItemPrivate::tagListInitialized() const
 
 MessageItem::MessageItem()
     : Item(Message, new MessageItemPrivate(this))
-    , ModelInvariantIndex()
+
 {
 }
 
 MessageItem::MessageItem(MessageItemPrivate *dd)
     : Item(Message, dd)
-    , ModelInvariantIndex()
+
 {
 }
 
@@ -515,10 +517,10 @@ QString MessageItem::accessibleText(const Theme *theme, int columnIndex)
             rightStrings.insert(rightStrings.begin(), accessibleTextForField(contentItem->type()));
         }
 
-        rowsTexts.append((leftStrings + rightStrings).join(QLatin1Char(' ')));
+        rowsTexts.append((leftStrings + rightStrings).join(u' '));
     }
 
-    return rowsTexts.join(QLatin1Char(' '));
+    return rowsTexts.join(u' ');
 }
 
 void MessageItem::subTreeToList(QList<MessageItem *> &list)
@@ -598,8 +600,7 @@ void FakeItem::setFakeTags(const QList<MessageItem::Tag *> &tagList)
 }
 
 TagCache::TagCache()
-    : QObject()
-    , mMonitor(new Akonadi::Monitor(this))
+    : mMonitor(new Akonadi::Monitor(this))
 {
     mCache.setMaxCost(100);
     mMonitor->setObjectName(QLatin1StringView("MessageListTagCacheMonitor"));
