@@ -48,7 +48,7 @@ public:
     void setCurrentFolder(const QModelIndex &etmIndex);
     void onNewTabClicked();
     void onCloseTabClicked();
-    void activateTab();
+    void activateTab(int i);
     void closeTab(QWidget *);
     void onCurrentTabChanged();
     void onTabContextMenuRequest(const QPoint &pos);
@@ -152,7 +152,14 @@ Pane::Pane(bool restoreSession, QAbstractItemModel *model, QItemSelectionModel *
     setMovable(true);
 
     connect(this, &Pane::currentChanged, this, [this]() {
-        d->onCurrentTabChanged();
+        // calling onCurrentTabChanged will emit q->currentTabChanged();
+        // In kmail we will try to get new currentCollection but
+        // it's not defined yet as we create a new tab
+        // => we can't see new message...
+        // call this method when we created new tab
+        if (!d->mPreferEmptyTab) {
+            d->onCurrentTabChanged();
+        }
     });
 
     setContextMenuPolicy(Qt::CustomContextMenu);
@@ -181,8 +188,8 @@ void Pane::PanePrivate::addActivateTabAction(int i)
     auto action = new QAction(i18nc("@action", "Activate Tab %1", i), q);
     mXmlGuiClient->actionCollection()->addAction(actionname, action);
     mXmlGuiClient->actionCollection()->setDefaultShortcut(action, QKeySequence(u"Alt+%1"_s.arg(i)));
-    connect(action, &QAction::triggered, q, [this]() {
-        activateTab();
+    connect(action, &QAction::triggered, q, [this, i]() {
+        activateTab(i);
     });
 }
 
@@ -512,39 +519,36 @@ void Pane::PanePrivate::setCurrentFolder(const QModelIndex &etmIndex)
     QString label;
     QIcon icon;
     QString toolTip;
-    for (const QModelIndex &index : s->selectedRows()) {
-        label += index.data(Qt::DisplayRole).toString() + QLatin1StringView(", ");
-    }
-    label.chop(2);
-
-    if (label.isEmpty()) {
+    if (s->selectedRows().isEmpty()) {
         label = i18nc("@title:tab Empty messagelist", "Empty");
         icon = QIcon();
     } else if (s->selectedRows().size() == 1) {
-        icon = s->selectedRows().first().data(Qt::DecorationRole).value<QIcon>();
-        QModelIndex idx = s->selectedRows().first().parent();
+        const QModelIndex firstModelIndex = s->selectedRows().first();
+        label = firstModelIndex.data(Qt::DisplayRole).toString();
         toolTip = label;
+        icon = firstModelIndex.data(Qt::DecorationRole).value<QIcon>();
+        QModelIndex idx = firstModelIndex.parent();
         while (idx != QModelIndex()) {
             toolTip = idx.data().toString() + u'/' + toolTip;
             idx = idx.parent();
         }
-    } else {
-        icon = QIcon::fromTheme(u"folder"_s);
     }
 
     const int index = q->indexOf(w);
     q->setTabText(index, label);
     q->setTabIcon(index, icon);
+    w->setDefaultCollectionIcon(icon);
     q->setTabToolTip(index, toolTip);
     if (mPreferEmptyTab) {
         mSelectionModel->select(mapSelectionFromSource(s->selection()), QItemSelectionModel::ClearAndSelect);
+        onCurrentTabChanged();
     }
     mPreferEmptyTab = false;
 }
 
-void Pane::PanePrivate::activateTab()
+void Pane::PanePrivate::activateTab(int index)
 {
-    q->tabBar()->setCurrentIndex(QStringView(q->sender()->objectName()).right(2).toInt() - 1);
+    q->tabBar()->setCurrentIndex(index - 1);
 }
 
 void Pane::PanePrivate::moveTabRight()
@@ -748,7 +752,7 @@ void Pane::PanePrivate::onTabContextMenuRequest(const QPoint &pos)
         auto tab = qobject_cast<Widget *>(q->widget(indexBar));
         const bool isLocked = !tab->isLocked();
         tab->setLockTab(isLocked);
-        q->setTabIcon(indexBar, isLocked ? QIcon::fromTheme(u"lock"_s) : QIcon::fromTheme(QStringLiteral("unlock")));
+        q->setTabIcon(indexBar, isLocked ? QIcon::fromTheme(u"lock"_s) : tab->defaultCollectionIcon());
         q->tabBar()->tabButton(indexBar, QTabBar::RightSide)->setEnabled(!isLocked);
         if (q->tabBar()->currentIndex() == indexBar) {
             mCloseTabButton->setEnabled(!isLocked);
@@ -800,7 +804,11 @@ void Pane::updateTabIconText(const Akonadi::Collection &collection, const QStrin
         if (w && (w->currentCollection() == collection)) {
             const int index = indexOf(w);
             setTabText(index, label);
-            setTabIcon(index, icon);
+            // We don't want to change icon if it's locked
+            if (!w->isLocked()) {
+                setTabIcon(index, icon);
+            }
+            w->setDefaultCollectionIcon(icon);
         }
     }
 }
@@ -838,7 +846,7 @@ QItemSelectionModel *Pane::createNewTab()
     connect(w, &Core::Widget::unlockTabRequested, this, [this, w]() {
         for (int i = 0; i < count(); ++i) {
             if (w == qobject_cast<Widget *>(widget(i))) {
-                setTabIcon(i, QIcon::fromTheme(u"unlock"_s));
+                setTabIcon(i, w->defaultCollectionIcon());
             }
         }
     });
