@@ -1,14 +1,14 @@
 /*
-   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #pragma once
 
-#include <QObject>
-
 #include "messageviewer_export.h"
+#include <QObject>
+#include <memory>
 namespace MessageViewer
 {
 class MessageViewerConfigureSettingsPluginPrivate;
@@ -21,7 +21,7 @@ class MESSAGEVIEWER_EXPORT MessageViewerConfigureSettingsPlugin : public QObject
     Q_OBJECT
 public:
     explicit MessageViewerConfigureSettingsPlugin(QObject *parent = nullptr);
-    ~MessageViewerConfigureSettingsPlugin();
+    ~MessageViewerConfigureSettingsPlugin() override;
 
     virtual void showConfigureDialog(QWidget *parent);
 
@@ -29,6 +29,6 @@ Q_SIGNALS:
     void configChanged();
 
 private:
-    MessageViewerConfigureSettingsPluginPrivate *const d;
+    std::unique_ptr<MessageViewerConfigureSettingsPluginPrivate> const d;
 };
 }
